#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-fixity-plugin
version:              2.2.0.0
visibility:           public
id:                   hls-explicit-fixity-plugin-2.2.0.0-3xV5ECSIN7YJutrTFYKIUB
key:                  hls-explicit-fixity-plugin-2.2.0.0-3xV5ECSIN7YJutrTFYKIUB
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Show fixity explicitly while hovering
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-explicit-fixity-plugin#readme>

category:             Development
abi:                  42ec3154662ebcfb9f80203d4cc55563
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFixity
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-fixity-plugin-2.2.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-fixity-plugin-2.2.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-fixity-plugin-2.2.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-fixity-plugin
hs-libraries:         HShls-explicit-fixity-plugin-2.2.0.0-3xV5ECSIN7YJutrTFYKIUB
depends:
    base-4.18.2.1 containers-0.6.7 deepseq-1.4.8.1
    extra-1.7.16-AZZkJf8uXcBmNBZ3QBrWg ghc-9.6.6
    ghcide-2.2.0.0-A7bgaULCXeX9IRF5j2vaTv
    hashable-1.4.7.0-H6imxCsecEO4wNDTcxh8s7
    hls-plugin-api-2.2.0.0-CJlumqKcZFmEjFCUieU5XS
    lsp-2.2.0.0-CukKTvdVHsT6La4UfPeciM text-2.0.2 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-fixity-plugin/html/hls-explicit-fixity-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-fixity-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

